@@ -16,12 +16,14 @@
 #  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
 #  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
 #  Vestibulum commodo. Ut rhoncus gravida arcu.
-import sys
+import json
 
 try:
-    from aiges_embed import ResponseData, Response, DataListNode, DataListCls  # c++
+    from aiges_embed import ResponseData, Response, DataListNode, DataListCls, SessionCreateResponse  # c++
 except:
-    from aiges.dto import Response, ResponseData, DataListNode, DataListCls
+    from aiges.dto import Response, ResponseData, DataListNode, DataListCls, SessionCreateResponse
+
+from aiges.sdk import SessionManager
 
 import hashlib
 from aiges.sdk import WrapperBase, \
@@ -29,47 +31,46 @@ from aiges.sdk import WrapperBase, \
     ImageBodyField, \
     StringBodyField
 from aiges.utils.log import log
-
-'''
-定义请求类:
- params:  params 开头的属性代表最终HTTP协议中的功能参数parameters部分， 
-          params Field支持 StringParamField，
-          NumberParamField，BooleanParamField,IntegerParamField，每个字段均支持枚举
-          params 属性多用于协议中的控制字段，请求body字段不属于params范畴
-
- input:    input字段多用与请求数据段，即body部分，当前支持 ImageBodyField, StringBodyField, 和AudioBodyField
-'''
+from aiges.core.types import *
 
 
 class UserRequest(object):
+    """
+    定义请求类:
+     params:  params 开头的属性代表最终HTTP协议中的功能参数parameters部分，
+              params Field支持 StringParamField，
+              NumberParamField，BooleanParamField,IntegerParamField，每个字段均支持枚举
+              params 属性多用于协议中的控制字段，请求body字段不属于params范畴
+
+     input:    input字段多用与请求数据段，即body部分，当前支持 ImageBodyField, StringBodyField, 和AudioBodyField
+    """
+
     params1 = StringParamField(key="p1", enums=["3", "eee"], value='3')
     params2 = StringParamField(key="p2", maxLength=44, required=True)
     params3 = StringParamField(key="p3", maxLength=44, required=False)
 
-    input1 = ImageBodyField(key="data", path="test_data/test.png")
-    input3 = ImageBodyField(key="data2", path="test_data/test.png")
-    input2 = StringBodyField(key="switch", value="cc")
-
-
-'''
-定义响应类:
- accepts:  accepts代表响应中包含哪些字段, 以及数据类型
-
- input:    input字段多用与请求数据段，即body部分，当前支持 ImageBodyField, StringBodyField, 和AudioBodyField
-'''
+    input1 = ImageBodyField(key="data", path="aiges/test_data/test.png")
+    input3 = ImageBodyField(key="data2", path="aiges/test_data/test.png")
+    input2 = StringBodyField(key="switch", value=b"")
 
 
 class UserResponse(object):
+    """
+    定义响应类:
+     accepts:  accepts代表响应中包含哪些字段, 以及数据类型
+
+     input:    input字段多用与请求数据段，即body部分，当前支持 ImageBodyField, StringBodyField, 和AudioBodyField
+    """
+
     accept1 = StringBodyField(key="boxes")
     accept2 = StringBodyField(key="boxes2")
 
 
-'''
-用户实现， 名称必须为Wrapper, 必须继承SDK中的 WrapperBase类
-'''
-
-
 class Wrapper(WrapperBase):
+    """
+    用户实现， 名称必须为Wrapper, 必须继承SDK中的 WrapperBase类
+    """
+
     serviceId = "mmocr"
     version = "backup.0"
     requestCls = UserRequest()
@@ -85,9 +86,12 @@ class Wrapper(WrapperBase):
         ret: 错误码。无错误时返回0
     '''
 
-    def wrapperInit(cls, config: {}) -> int:
+    def wrapperInit(self, config: {}) -> int:
         print(config)
         print("Initializing ..")
+        # 会话模式创建sessionManager
+        self.session.init_wrapper_config(config)
+
         return 0
 
     '''
@@ -131,8 +135,9 @@ class Wrapper(WrapperBase):
         # return r.response_err(100)
         l = ResponseData()
         l.key = "ccc"
-        l.status = 1
+        l.status = DataOnce
         d = open("test_data/test.png", "rb").read()
+        d = "cc"
         l.len = len(d)
         l.data = d
         l.type = 0
@@ -159,7 +164,7 @@ class Wrapper(WrapperBase):
         l = ResponseData()
         l.key = "ccc"
         l.status = 1
-        d = open("pybind11/docs/pybind11-logo.png", "rb").read()
+        d = open("pybind11/docs/pybind11-logo.png", "r").read()
         l.len = len(d)
         l.data = d
         r.list = [l, l, l]
@@ -168,8 +173,57 @@ class Wrapper(WrapperBase):
         print(444)
         return r
 
+    def wrapperCreate(self, params: {}, sid: str) -> SessionCreateResponse:
+        print(params)
+        s = SessionCreateResponse()
+        # 这里是取 handle
+        handle = self.session.get_idle_handle()
+
+        if not handle:
+            s.error_code = -1
+            s.handle = ""
+            return s
+        _session = self.session.get_session(handle=handle)
+        _session.setup_sid(sid)
+        _session.setup_params(params)
+
+        print(sid)
+        s = SessionCreateResponse()
+        s.handle = handle
+        s.error_code = 0
+        return s
+
+    def wrapperWrite(self, handle: str, req: DataListCls, sid: str) -> int:
+        print("handle", handle)
+        print("sid:", sid)
+        print("req:", req)
+        for i in req.list:
+            print(i.key)
+            print(i.data)
+        return 0
+
+    def wrapperRead(self, handle: str, sid: str) -> Response:
+        print("handle", handle)
+        print("sid:", sid)
+        _session = self.session.get_session(handle=handle)
+        print("out.q", _session.out_q)
+        r = Response()
+        l = ResponseData()
+
+        l.key = "ccc"
+        l.status = 1
+        d = "cccccc"
+        l.len = len(d)
+        l.data = d
+        r.list = [l]
+        return r
+
 
 if __name__ == '__main__':
-    m = Wrapper()
-    m.schema()
-    m.run()
+    m = Wrapper(legacy=False, is_aipaas=True, keep_schema_default_value=False)
+    c = m.schema()
+    f = open("out.json", "w")
+    c = json.loads(c)
+    print(type(c))
+    print(json.dump(c, f, indent=4))
+    # m.run()
